@@ -1,4 +1,4 @@
-use anyhow::Result;
+use anyhow::{bail, Result};
 use asyncgit::StatusItem;
 use std::{
     collections::BTreeSet,
@@ -75,9 +75,7 @@ impl FileTreeItem {
                 ),
                 kind: FileTreeItemKind::File(item.clone()),
             }),
-            None => {
-                Err(anyhow::anyhow!("invalid file name {:?}", item))
-            }
+            None => bail!("invalid file name {:?}", item),
         }
     }
 
@@ -102,10 +100,7 @@ impl FileTreeItem {
                     collapsed,
                 )),
             }),
-
-            None => Err(anyhow::anyhow!(
-                "failed to create item from path"
-            )),
+            None => bail!("failed to create item from path"),
         }
     }
 }
@@ -186,24 +181,17 @@ impl FileTreeItems {
     }
 
     ///
-    pub(crate) fn find_parent_index(
-        &self,
-        path: &str,
-        index: usize,
-    ) -> usize {
-        if let Some(parent_path) = Path::new(path).parent() {
-            let parent_path =
-                parent_path.to_str().expect("invalid path");
-            for i in (0..=index).rev() {
-                let item = &self.items[i];
-                let item_path = &item.info.full_path;
-                if item_path == parent_path {
-                    return i;
-                }
+    pub(crate) fn find_parent_index(&self, index: usize) -> usize {
+        let item_indent = &self.items[index].info.indent;
+        let mut parent_index = index;
+        while item_indent <= &self.items[parent_index].info.indent {
+            if parent_index == 0 {
+                return 0;
             }
+            parent_index -= 1;
         }
 
-        0
+        parent_index
     }
 
     fn push_dirs<'a>(
@@ -232,6 +220,25 @@ impl FileTreeItems {
 
         Ok(())
     }
+
+    pub fn multiple_items_at_path(&self, index: usize) -> bool {
+        let tree_items = self.items();
+        let mut idx_temp_inner;
+        if index + 2 < tree_items.len() {
+            idx_temp_inner = index + 1;
+            while idx_temp_inner < tree_items.len().saturating_sub(1)
+                && tree_items[index].info.indent
+                    < tree_items[idx_temp_inner].info.indent
+            {
+                idx_temp_inner += 1;
+            }
+        } else {
+            return false;
+        }
+
+        tree_items[idx_temp_inner].info.indent
+            == tree_items[index].info.indent
+    }
 }
 
 impl IndexMut<usize> for FileTreeItems {
@@ -377,6 +384,29 @@ mod tests {
         );
     }
 
+    #[test]
+    fn test_multiple_items_at_path() {
+        //0 a/
+        //1   b/
+        //2     c/
+        //3       d
+        //4     e/
+        //5       f
+
+        let res = FileTreeItems::new(
+            &string_vec_to_status(&[
+                "a/b/c/d", //
+                "a/b/e/f", //
+            ]),
+            &BTreeSet::new(),
+        )
+        .unwrap();
+
+        assert_eq!(res.multiple_items_at_path(0), false);
+        assert_eq!(res.multiple_items_at_path(1), false);
+        assert_eq!(res.multiple_items_at_path(2), true);
+    }
+
     #[test]
     fn test_find_parent() {
         //0 a/
@@ -393,9 +423,6 @@ mod tests {
         )
         .unwrap();
 
-        assert_eq!(
-            res.find_parent_index(&String::from("a/b/c"), 3),
-            1
-        );
+        assert_eq!(res.find_parent_index(3), 1);
     }
 }
