@@ -73,8 +73,12 @@ pub enum QueueEvent {
     InputEvent(InputEvent),
 }
 
+struct CliArgs {
+    theme: PathBuf,
+}
+
 fn main() -> Result<()> {
-    process_cmdline()?;
+    let cliargs = process_cmdline()?;
 
     let _profiler = Profiler::new();
 
@@ -100,7 +104,7 @@ fn main() -> Result<()> {
     let ticker = tick(TICK_INTERVAL);
     let spinner_ticker = tick(SPINNER_INTERVAL);
 
-    let mut app = App::new(&tx_git, input);
+    let mut app = App::new(&tx_git, input, cliargs.theme);
 
     let mut spinner = Spinner::default();
     let mut first_update = true;
@@ -240,8 +244,12 @@ fn get_app_cache_path() -> Result<PathBuf> {
 }
 
 fn get_app_config_path() -> Result<PathBuf> {
-    let mut path = dirs_next::config_dir()
-        .ok_or_else(|| anyhow!("failed to find os config dir."))?;
+    let mut path = if cfg!(target_os = "macos") {
+        dirs_next::home_dir().map(|h| h.join(".config"))
+    } else {
+        dirs_next::config_dir()
+    }
+    .ok_or_else(|| anyhow!("failed to find os config dir."))?;
 
     path.push("gitui");
     fs::create_dir_all(&path)?;
@@ -261,11 +269,19 @@ fn setup_logging() -> Result<()> {
     Ok(())
 }
 
-fn process_cmdline() -> Result<()> {
+fn process_cmdline() -> Result<CliArgs> {
     let app = ClapApp::new(crate_name!())
         .author(crate_authors!())
         .version(crate_version!())
         .about(crate_description!())
+        .arg(
+            Arg::with_name("theme")
+                .help("Set the color theme (defaults to theme.ron)")
+                .short("t")
+                .long("theme")
+                .value_name("THEME")
+                .takes_value(true),
+        )
         .arg(
             Arg::with_name("logging")
                 .help("Stores logging output into a cache directory")
@@ -290,8 +306,17 @@ fn process_cmdline() -> Result<()> {
             arg_matches.value_of("directory").unwrap_or(".");
         env::set_current_dir(directory)?;
     }
-
-    Ok(())
+    let arg_theme =
+        arg_matches.value_of("theme").unwrap_or("theme.ron");
+    if get_app_config_path()?.join(arg_theme).is_file() {
+        Ok(CliArgs {
+            theme: get_app_config_path()?.join(arg_theme),
+        })
+    } else {
+        Ok(CliArgs {
+            theme: get_app_config_path()?.join("theme.ron"),
+        })
+    }
 }
 
 fn set_panic_handlers() -> Result<()> {
