@@ -29,6 +29,8 @@ pub enum Action {
     ResetHunk(String, u64),
     StashDrop(CommitId),
     DeleteBranch(String),
+    ForcePush(String, bool),
+    PullMerge(usize),
 }
 
 ///
@@ -60,7 +62,9 @@ pub enum InternalEvent {
     ///
     OpenExternalEditor(Option<String>),
     ///
-    Push(String),
+    Push(String, bool),
+    ///
+    Pull(String),
 }
 
 ///
