@@ -1,4 +1,6 @@
-use crate::get_app_config_path;
+//TODO: remove once fixed https://github.com/rust-lang/rust-clippy/issues/6818
+#![allow(clippy::use_self)]
+
 use anyhow::Result;
 use asyncgit::{DiffLineType, StatusItemType};
 use ron::{
@@ -230,19 +232,14 @@ impl Theme {
             .bg(self.push_gauge_bg)
     }
 
-    fn save(&self) -> Result<()> {
-        let theme_file = Self::get_theme_file()?;
+    // This will only be called when theme.ron doesn't already exists
+    fn save(&self, theme_file: PathBuf) -> Result<()> {
         let mut file = File::create(theme_file)?;
         let data = to_string_pretty(self, PrettyConfig::default())?;
         file.write_all(data.as_bytes())?;
         Ok(())
     }
 
-    fn get_theme_file() -> Result<PathBuf> {
-        let app_home = get_app_config_path()?;
-        Ok(app_home.join("theme.ron"))
-    }
-
     fn read_file(theme_file: PathBuf) -> Result<Self> {
         let mut f = File::open(theme_file)?;
         let mut buffer = Vec::new();
@@ -250,21 +247,21 @@ impl Theme {
         Ok(from_bytes(&buffer)?)
     }
 
-    fn init_internal() -> Result<Self> {
-        let file = Self::get_theme_file()?;
-        if file.exists() {
-            Ok(Self::read_file(file)?)
+    fn init_internal(theme: PathBuf) -> Result<Self> {
+        if theme.exists() {
+            Ok(Self::read_file(theme)?)
         } else {
+            // This will only be called when theme.ron doesn't already exists
             let def = Self::default();
-            if def.save().is_err() {
+            if def.save(theme).is_err() {
                 log::warn!("failed to store default theme to disk.")
             }
             Ok(def)
         }
     }
 
-    pub fn init() -> Self {
-        Self::init_internal().unwrap_or_default()
+    pub fn init(theme_path: PathBuf) -> Self {
+        Self::init_internal(theme_path).unwrap_or_default()
     }
 }
 
